CommentBox class

Inheritance

Constructors

CommentBox({Widget? child, Widget? header, dynamic sendButtonMethod, dynamic formKey, dynamic commentController, Widget? sendWidget, ImageProvider<Object>? userImage, String? labelText, FocusNode? focusNode, String? errorText, bool withBorder = true, Color? backgroundColor, Color? textColor})

Properties

backgroundColor ↔ Color?
getter/setter pair
child ↔ Widget?
getter/setter pair
commentController ↔ dynamic
getter/setter pair
errorText ↔ String?
getter/setter pair
focusNode ↔ FocusNode?
getter/setter pair
formKey ↔ dynamic
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
getter/setter pair
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
labelText ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sendButtonMethod ↔ dynamic
getter/setter pair
sendWidget ↔ Widget?
getter/setter pair
textColor ↔ Color?
getter/setter pair
userImage ↔ ImageProvider<Object>?
getter/setter pair
withBorder ↔ bool
getter/setter pair

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

commentImageParser({dynamic imageURLorPath}) → ImageProvider<Object>
This method is used to parse the image from the URL or the path. CommentBox.commentImageParser(imageURLorPath: 'url_or_path_to_image')